Module smdiff_encoder::brotli

source ·
This module is a re-export of the brotli encoder used in the secondary compression. It also exports the config options.

Structs

Enums

  • Allows to tune a brotli compressor for a specific type of input.