Module smdiff_encoder::writer

source ·
A writer for an smdiff section. This handles writing the header and the operations, and optionally secondary compression.

Functions

  • Writes a section to a writer, with secondary compression if requested.