Module smdiff_encoder::zstd
source · Expand description
This module is a re-export of the zstd encoder used in the secondary compression.
Structs
- An encoder that compress and forward data to another writer.
This module is a re-export of the zstd encoder used in the secondary compression.