Module smdiff_encoder::brotli
source · Expand description
This module is a re-export of the brotli encoder used in the secondary compression. It also exports the config options.
Structs
- The recommended input block size (in bits) to use for compression.
- Compression options to be used for a
BrotliEncoder. - Wraps a writer and compresses its output.
- Quality level of the brotli compression
- The sliding window size (in bits) to use for compression.
Enums
- Allows to tune a brotli compressor for a specific type of input.